@@ -8,8 +8,9 @@ import http.client
 import sys
 import threading
 import time
-import urllib.request, urllib.parse, urllib.error
-import re
+import urllib.request
+import urllib.parse
+import urllib.error
 
 from bottle import abort, request, HTTPResponse, redirect, app
 from oauthlib.common import to_unicode
